@@ -853,9 +853,9 @@ def get_build_info() -> BuildInfo:
     """
 
     return BuildInfo(
-        version="0.7.0",
-        build="05/08/2022-10:49:12",
-        hash="0x95d6cf14",
+        version="0.8.1",
+        build="13/12/2022-09:29:06",
+        hash="0x6C0C23BA",
         dirty=False
     )
 
