@@ -1,6 +1,10 @@
 from qblox_instruments.ieee488_2.transport import Transport
 from qblox_instruments.ieee488_2.ip_transport import IpTransport
-from qblox_instruments.ieee488_2.dummy_transport import DummyTransport
+from qblox_instruments.ieee488_2.dummy_transport import (
+        DummyTransport,
+        DummyBinnedAcquisitionData,
+        DummyScopeAcquisitionData,
+)
 from qblox_instruments.ieee488_2.qcm_qrm_dummy_transport import QcmQrmDummyTransport
 from qblox_instruments.ieee488_2.pulsar_dummy_transport import PulsarDummyTransport
 from qblox_instruments.ieee488_2.cluster_dummy_transport import ClusterDummyTransport
