@@ -9,9 +9,14 @@
 
 import json
 
-from typing import Dict, Optional, Union
+from typing import Dict, Optional, Union, Iterable
 from qblox_instruments import ClusterType
-from qblox_instruments.ieee488_2 import DummyTransport, QcmQrmDummyTransport
+from qblox_instruments.ieee488_2 import (
+        DummyTransport,
+        QcmQrmDummyTransport,
+        DummyBinnedAcquisitionData,
+        DummyScopeAcquisitionData,
+)
 
 
 # -- class -------------------------------------------------------------------
@@ -242,3 +247,58 @@ class ClusterDummyTransport(DummyTransport):
                 mod_present |= 1 << (int(slot_idx) - 1)
 
         self._data_out = mod_present
+
+    # ------------------------------------------------------------------------
+    def set_dummy_binned_acquisition_data(
+            self,
+            slot_idx: int,
+            sequencer: int,
+            acq_index_name: str,
+            data: Iterable[Union[DummyBinnedAcquisitionData, None]]):
+        """
+        Set dummy binned acquisition data for the dummy.
+
+        Parameters
+        ----------
+        slot_idx : int
+            Slot of the hardware you want to set the data to on a cluster.
+        sequencer : int
+            Sequencer.
+        acq_index_name : str
+            Acquisition index name.
+        data : Iterable[Union[DummyBinnedAcquisitionData, None]]
+            Dummy data for the binned acquisition.
+            An iterable of all the bin values.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        self._modules[str(slot_idx)].set_dummy_binned_acquisition_data(sequencer, acq_index_name, data)
+
+
+    # ------------------------------------------------------------------------
+    def set_dummy_scope_acquisition_data(
+            self,
+            slot_idx: int,
+            data: DummyScopeAcquisitionData):
+        """
+        Set dummy scope acquisition data for the dummy.
+
+        Parameters
+        ----------
+        slot_idx : int
+            Slot of the hardware you want to set the data to on a cluster.
+        data : DummyScopeAcquisitionData
+             Dummy data for the scope acquisition.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        self._modules[str(slot_idx)].set_dummy_scope_acquisition_data(data)
