@@ -11,10 +11,15 @@ import os
 import sys
 import struct
 import subprocess
+from copy import deepcopy
 
-from typing import Union
+from typing import Union, Iterable, Dict
 from qblox_instruments import PulsarType, ClusterType
-from qblox_instruments.ieee488_2 import DummyTransport
+from qblox_instruments.ieee488_2 import (
+        DummyTransport,
+        DummyBinnedAcquisitionData,
+        DummyScopeAcquisitionData,
+)
 
 
 # -- class -------------------------------------------------------------------
@@ -84,7 +89,9 @@ class QcmQrmDummyTransport(DummyTransport):
         self._awg_waveforms = {}
         self._acq_weights = {}
         self._acq_acquisitions = {}
+        self._acq_scope_acquisition = None
         self._channelmap = {}
+        self._port_cfg = {}
 
         # Set command dictionary
         self._cmds["LO:PRESent?"] = self._get_lo_hw_present
@@ -128,6 +135,10 @@ class QcmQrmDummyTransport(DummyTransport):
         self._cmds["SEQuencer#:ACQ:ALISt?"] = self._get_acq_acquisitions
         self._cmds["SEQuencer#:CHANnelmap"] = self._set_channelmap
         self._cmds["SEQuencer#:CHANnelmap?"] = self._get_channelmap
+        self._cmds["AFE:ATT:OUT#"] = self._set_out_att
+        self._cmds["AFE:ATT:OUT#?"] = self._get_out_att
+        self._cmds["AFE:ATT:IN#"] = self._set_in_att
+        self._cmds["AFE:ATT:IN#?"] = self._get_in_att
 
     # ------------------------------------------------------------------------
     @property
@@ -189,6 +200,105 @@ class QcmQrmDummyTransport(DummyTransport):
 
         return self._type_handle.is_rf_type
 
+    # ------------------------------------------------------------------------
+    def set_dummy_binned_acquisition_data(
+            self,
+            sequencer: int,
+            acq_index_name: str,
+            data: Iterable[Union[DummyBinnedAcquisitionData, None]]):
+        """
+        Set dummy binned acquisition data for the dummy.
+
+        Parameters
+        ----------
+        sequencer : int
+            Sequencer.
+        acq_index_name : str
+            Acquisition index name.
+        data : Iterable[Union[DummyBinnedAcquisitionData, None]]
+            Dummy data for the binned acquisition.
+            An iterable of all the bin values.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        def _unnormalized_int(single_data: DummyBinnedAcquisitionData):
+            sample_width = 12
+            max_sample_value = 2 ** (sample_width - 1) - 1
+            max_sample_value_sqrd = max_sample_value ** 2
+
+            int0, int1 = single_data.data[0], single_data.data[1]
+            int0 *= max_sample_value_sqrd * (single_data.avg_cnt or 1)
+            int1 *= max_sample_value_sqrd * (single_data.avg_cnt or 1)
+            return [round(int0), round(int1)]
+
+        sequencer = str(sequencer)
+        if sequencer not in self._acq_acquisitions:
+            self._acq_acquisitions[sequencer] = {}
+
+        bins = []
+        for single_data in data:
+            if single_data is None:
+                bins.append({
+                    "valid": False,
+                    "int": [0, 0],
+                    "thres": 0,
+                    "avg_cnt": 0})
+            else:
+                bins.append({
+                    "valid": True,
+                    "int": _unnormalized_int(single_data),
+                    "thres": round(single_data.thres * (single_data.avg_cnt or 1)),
+                    "avg_cnt": single_data.avg_cnt})
+
+        if acq_index_name not in self._acq_acquisitions[sequencer]:
+            self._acq_acquisitions[sequencer][acq_index_name] = {}
+        if "acq" not in self._acq_acquisitions[sequencer][acq_index_name]:
+            self._acq_acquisitions[sequencer][acq_index_name]["acq"] = {}
+        self._acq_acquisitions[sequencer][acq_index_name]["acq"]["bins"] = bins
+
+    # ------------------------------------------------------------------------
+    def set_dummy_scope_acquisition_data(
+            self,
+            data: DummyScopeAcquisitionData):
+        """
+        Set dummy scope acquisition data for the dummy.
+
+        Parameters
+        ----------
+        data : DummyScopeAcquisitionData
+             Dummy data for the scope acquisition.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+
+        def _unnormalized_int(val, avg_cnt):
+            sample_width = 12
+            max_sample_value = 2 ** (sample_width - 1) - 1
+            return round(val * max_sample_value * (avg_cnt or 1))
+
+        def _pack_data(data):
+            return struct.pack("i" * len(data), *data)
+
+        converted_data = ([], [])
+        for single_data in data.data:
+            converted_data[0].append(_unnormalized_int(single_data[0], data.avg_cnt[0]))
+            converted_data[1].append(_unnormalized_int(single_data[1], data.avg_cnt[1]))
+
+        self._acq_scope_acquisition = {
+            "data": (_pack_data(converted_data[0]), _pack_data(converted_data[1])),
+            "or": data.out_of_range,
+            "avg_cnt": data.avg_cnt,
+        }
+
     # ------------------------------------------------------------------------
     def _get_lo_hw_present(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
         """
@@ -1209,20 +1319,24 @@ class QcmQrmDummyTransport(DummyTransport):
             self._acq_acquisitions[cmd_params[0]] = {}
             index = 0
 
-        self._acq_acquisitions[cmd_params[0]][cmd_args[0]] = {
-            "acq": {
-                "scope": {
-                    "data": [bytearray([]), bytearray([])],
-                    "or": [False, False],
-                    "avg_cnt": [0, 0],
-                },
-                "bins": [
-                    {"valid": False, "int": [0, 0], "thres": 0, "avg_cnt": 0}
-                    for _ in range(0, int(cmd_args[1]))
-                ],
-            },
-            "index": index,
-        }
+        if cmd_args[0] not in self._acq_acquisitions[cmd_params[0]]:
+            self._acq_acquisitions[cmd_params[0]][cmd_args[0]] = {}
+
+        self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["index"] = index
+
+        if "acq" not in self._acq_acquisitions[cmd_params[0]][cmd_args[0]]:
+            self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"] = {}
+        if "scope" not in self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]:
+            self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["scope"] = {
+                "data": [bytearray([]), bytearray([])],
+                "or": [False, False],
+                "avg_cnt": [0, 0],
+            }
+        if "bins" not in self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]:
+            self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["bins"] = [
+                {"valid": False, "int": [0, 0], "thres": 0, "avg_cnt": 0}
+                for _ in range(int(cmd_args[1]))
+            ]
 
     # ------------------------------------------------------------------------
     def _del_acq_acquisition(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
@@ -1283,17 +1397,8 @@ class QcmQrmDummyTransport(DummyTransport):
 
         if cmd_params[0] in self._acq_acquisitions:
             if cmd_args[0] in self._acq_acquisitions[cmd_params[0]]:
-                sample_width = 12
-                max_sample_value = 2 ** (sample_width - 1) - 1
-                size = 2 ** 14
-                self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["scope"]["data"][0] = struct.pack(
-                    "i" * size,
-                    *[int(max_sample_value / size) * i for i in range(0, size)]
-                )
-                self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["scope"]["data"][1] = struct.pack(
-                    "i" * size,
-                    *[max_sample_value - int(max_sample_value / size) * i for i in range(0, size)]
-                )
+                if self._acq_scope_acquisition is not None:
+                    self._acq_acquisitions[cmd_params[0]][cmd_args[0]]["acq"]["scope"] = self._acq_scope_acquisition
                 return
         error = "Acquisition {} does not exist in acquisition list.".format(cmd_args[0])
         self._system_error.append(error)
@@ -1662,3 +1767,106 @@ class QcmQrmDummyTransport(DummyTransport):
             channel_map = self._channelmap[cmd_params[0]]
         channel_map_packed = struct.pack("I" * len(channel_map), *channel_map)
         self._bin_out = self._encode_bin(channel_map_packed)
+        
+    # ------------------------------------------------------------------------
+    def _set_out_att(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Sets the output channel map
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        key = f"out{cmd_params[0]}"
+        port = self._port_cfg.get(key, {})
+        port["attenuation"] = cmd_args[0]
+        self._port_cfg[key] = port
+        
+    
+    # ------------------------------------------------------------------------
+    def _get_out_att(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Gets the output attenuation. If not set previously, returns 0
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        key = f"out{cmd_params[0]}"
+        port = self._port_cfg.get(key, {})
+        self._data_out = port.get("attenuation", 0)
+        
+
+    # ------------------------------------------------------------------------
+    def _set_in_att(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Sets the output channel map
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        key = f"in{cmd_params[0]}"
+        port = self._port_cfg.get(key, {})
+        port["attenuation"] = cmd_args[0]
+        self._port_cfg[key] = port
+        
+    
+    # ------------------------------------------------------------------------
+    def _get_in_att(self, cmd_params: list, cmd_args: list, bin_in: bytes) -> None:
+        """
+        Gets the output attenuation. If not set previously, returns 0
+
+        Parameters
+        ----------
+        cmd_params : list
+            Command parameters indicated by '#' in the command.
+        cmd_args : list
+            Command arguments.
+        bin_in : bytes
+            Binary input data.
+
+        Returns
+        ----------
+
+        Raises
+        ----------
+        """
+        key = f"in{cmd_params[0]}"
+        port = self._port_cfg.get(key, {})
+        self._data_out = port.get("attenuation", 0)
+        
+    
