@@ -993,10 +993,10 @@ def get_sequencer_config_format(is_qrm_type: bool) -> str:
     """
 
     seq_proc_cfg_format = "?I"
-    awg_cfg_format = "??IIIIIIIIIII?IIIIIII??I"
-    awg_float_cfg_format = "fdffffff"
-    acq_cfg_format = "II?IIIq"
-    acq_float_cfg_format = "ffd"
+    awg_cfg_format = "??IIIIIIIII?IIIII??I?i"
+    awg_float_cfg_format = "ddffffff"
+    acq_cfg_format = "???IIIIIIq"
+    acq_float_cfg_format = "fffd"
 
     qcm_cfg_format = seq_proc_cfg_format
     qcm_cfg_format += awg_cfg_format
@@ -1051,13 +1051,9 @@ def set_sequencer_config(funcs: FuncRefs, sequencer: int, config: Dict) -> None:
         0,                                              # Gain for AWG path 1         (unused)
         0,                                              # Offset for AWG path 0       (unused)
         0,                                              # Offset for AWG path 1       (unused)
-        0,                                              # Phase increment; ultra-fine (unused)
-        0,                                              # Phase increment; fine       (unused)
-        0,                                              # Phase increment; coarse     (unused)
+        0,                                              # Phase increment; frequency  (unused)
         0,                                              # Phase increment; sign       (unused)
-        0,                                              # Phase; ultra-fine           (unused)
-        0,                                              # Phase; fine                 (unused)
-        0,                                              # Phase; coarse               (unused)
+        0,                                              # Phase                       (unused)
         0,                                              # Mixer correction matrix a11 (unsued)
         0,                                              # Mixer correction matrix a12 (unsued)
         0,                                              # Mixer correction matrix a21 (unsued)
@@ -1065,10 +1061,12 @@ def set_sequencer_config(funcs: FuncRefs, sequencer: int, config: Dict) -> None:
         cfg_dict["mod_en_awg"],                         # Modulation enable for AWG paths 0 and 1
         cfg_dict["mrk_ovr_en"],                         # Marker override enable
         cfg_dict["mrk_ovr_val"],                        # Marker override value
+        cfg_dict["nco_prop_delay_comp_en"],             # NCO delay compensation enable
+        cfg_dict["nco_prop_delay_comp"],                # NCO delay compensation
 
         # AWG floating point values to be converted
-        cfg_dict["phase_offs_degree"],                     # Phase offset in degrees
         cfg_dict["freq_hz"],                               # Frequency in Hz
+        cfg_dict["phase_offs_degree"],                     # Phase offset in degrees
         cfg_dict["gain_awg_path_0_float"],                 # Gain for AWG path 0 as float
         cfg_dict["gain_awg_path_1_float"],                 # Gain for AWG path 1 as float
         cfg_dict["offset_awg_path_0_float"],               # Offset for AWG path 0 as float
@@ -1080,17 +1078,21 @@ def set_sequencer_config(funcs: FuncRefs, sequencer: int, config: Dict) -> None:
     if funcs.is_qrm_type():
         cfg += [
             # Acquisition
+            cfg_dict["demod_en_acq"],                 # Demodulation enable
+            cfg_dict["ttl_in"],                       # TTL Trigger acquisition input
+            cfg_dict["ttl_auto_bin_incr_en"],         # TTL Trigger acquisition auto bin increase
             cfg_dict["upsample_rate_acq_path_0"],     # Upsample rate for acquisition path 0
             cfg_dict["upsample_rate_acq_path_1"],     # Upsample rate for acquisition path 1
-            cfg_dict["demod_en_acq"],                 # Demodulation enable
             cfg_dict["non_weighed_integration_len"],  # Non weighed integration length
             0,                                        # Rotation matrix A11 (unused)
             0,                                        # Rotation matrix A12 (unused)
+            0,                                        # TTL Trigger acquisition threshold (unused)
             0,                                        # Discretization threshold (unused)
 
             # Acquisition floating point values to be converted
             cfg_dict["rotation_matrix_a11"],  # Rotation matrix A11
             cfg_dict["rotation_matrix_a12"],  # Rotation matrix A12
+            cfg_dict["ttl_threshold"],        # TTL Trigger acquisition threshold
             cfg_dict["discr_threshold"],      # Discretization threshold
         ]
 
@@ -1138,34 +1140,39 @@ def get_sequencer_config(funcs: FuncRefs, sequencer: int) -> Dict:
         "cont_mode_waveform_idx_awg_path_1": cfg[5],
         "upsample_rate_awg_path_0":          cfg[6],
         "upsample_rate_awg_path_1":          cfg[7],
-        "mod_en_awg":                        cfg[23],
-        "mrk_ovr_en":                        cfg[24],
-        "mrk_ovr_val":                       cfg[25],
-
+        "mod_en_awg":                        cfg[19],
+        "mrk_ovr_en":                        cfg[20],
+        "mrk_ovr_val":                       cfg[21],
+        "nco_prop_delay_comp_en":            cfg[22],
+        "nco_prop_delay_comp":               cfg[23],
         # AWG floating point values
-        "phase_offs_degree":                    cfg[26],
-        "freq_hz":                              cfg[27],
-        "gain_awg_path_0_float":                cfg[28],
-        "gain_awg_path_1_float":                cfg[29],
-        "offset_awg_path_0_float":              cfg[30],
-        "offset_awg_path_1_float":              cfg[31],
-        "mixer_corr_phase_offset_degree_float": cfg[32],
-        "mixer_corr_gain_ratio_float":          cfg[33],
+        "freq_hz":                              cfg[24],
+        "phase_offs_degree":                    cfg[25],
+        "gain_awg_path_0_float":                cfg[26],
+        "gain_awg_path_1_float":                cfg[27],
+        "offset_awg_path_0_float":              cfg[28],
+        "offset_awg_path_1_float":              cfg[29],
+        "mixer_corr_phase_offset_degree_float": cfg[30],
+        "mixer_corr_gain_ratio_float":          cfg[31],
     }
 
     if funcs.is_qrm_type():
         cfg_dict = {**cfg_dict, **{
             # Acquisition
-            "upsample_rate_acq_path_0":    cfg[34],
-            "upsample_rate_acq_path_1":    cfg[35],
-            "demod_en_acq":                cfg[36],
+            "demod_en_acq":                cfg[32],
+            "ttl_in":                      cfg[33],
+            "ttl_auto_bin_incr_en":        cfg[34],
+            "upsample_rate_acq_path_0":    cfg[35],
+            "upsample_rate_acq_path_1":    cfg[36],
             "non_weighed_integration_len": cfg[37],
 
             # Acquisition floating point values
-            "rotation_matrix_a11": cfg[41],
-            "rotation_matrix_a12": cfg[42],
-            "discr_threshold":     cfg[43]},
+            "rotation_matrix_a11": cfg[42],
+            "rotation_matrix_a12": cfg[43],
+            "ttl_threshold":       cfg[44],
+            "discr_threshold":     cfg[45]},
         }
+
     return cfg_dict
 
 
@@ -1757,6 +1764,10 @@ def _add_acq_acquisition(
         funcs._set_acq_acquisition_index(sequencer, name, index)
 
 
+# The _get_acq_data_and_convert method potentially does a division by zero
+# that we want to ignore.
+numpy.seterr(divide='ignore', invalid='ignore')
+
 # ----------------------------------------------------------------------------
 def _get_acq_data_and_convert(
     funcs: FuncRefs,
@@ -1820,37 +1831,32 @@ def _get_acq_data_and_convert(
         for val in acquisition_dict["scope"]["path1"]["data"]
     ]
 
-    # Retrieve bin data
+    # Convert to long values
     bins = funcs._read_bin("", flush_line_end)
-    bin_format = "QqqLL"
-    num_bins = int(len(bins) / struct.calcsize("=" + bin_format))
-    bins = struct.unpack("=" + bin_format * num_bins, bins)
-    for bin_idx in range(0, num_bins):
-        valid = bins[bin_idx * len(bin_format)]
-        if bool(valid):
-            bin_path0 = bins[bin_idx * len(bin_format) + 1]
-            bin_path1 = bins[bin_idx * len(bin_format) + 2]
-            thres = bins[bin_idx * len(bin_format) + 3]
-            avg_cnt = bins[bin_idx * len(bin_format) + 4]
+    bin_data = numpy.frombuffer(bins, dtype=numpy.int64).reshape(-1,4)
+    valid = bin_data[:,0].astype(bool)
+    path0_raw = bin_data[:,1]
+    path1_raw = bin_data[:,2]
+    thres_avg_cnt_raw = bin_data[:,3].astype(numpy.uint64)
 
-            # Normalize
-            bin_path0 /= max_sample_value_sqrd
-            bin_path1 /= max_sample_value_sqrd
-            thres = float(thres)
-            if avg_cnt != 0:
-                bin_path0 /= avg_cnt
-                bin_path1 /= avg_cnt
-                thres /= avg_cnt
-        else:
-            bin_path0 = float("NaN")
-            bin_path1 = float("NaN")
-            thres = float("NaN")
-            avg_cnt = float("NaN")
+    # Thresholded and average count are stored in the same long value so need
+    # to be separated. Thresholded is first in stream, thus lower 32 bits.
+    thres_raw = thres_avg_cnt_raw & 0xFFFFFFFF
+    avg_cnt = thres_avg_cnt_raw >> 32
 
-        acquisition_dict["bins"]["integration"]["path0"].append(bin_path0)
-        acquisition_dict["bins"]["integration"]["path1"].append(bin_path1)
-        acquisition_dict["bins"]["threshold"].append(thres)
-        acquisition_dict["bins"]["avg_cnt"].append(avg_cnt)
+    path0_raw = numpy.where(avg_cnt > 0, path0_raw / avg_cnt, path0_raw)
+    path1_raw = numpy.where(avg_cnt > 0, path1_raw / avg_cnt, path1_raw)
+    thres_raw = numpy.where(avg_cnt > 0, thres_raw / avg_cnt, thres_raw)
+
+    path0_data = numpy.where(valid, path0_raw / max_sample_value_sqrd, numpy.nan)
+    path1_data = numpy.where(valid, path1_raw / max_sample_value_sqrd, numpy.nan)
+    thres_data = numpy.where(valid, thres_raw, numpy.nan)
+    avg_cnt_data = numpy.where(valid, avg_cnt, numpy.nan)
+
+    acquisition_dict["bins"]["integration"]["path0"] = path0_data.tolist()
+    acquisition_dict["bins"]["integration"]["path1"] = path1_data.tolist()
+    acquisition_dict["bins"]["threshold"] = thres_data.tolist()
+    acquisition_dict["bins"]["avg_cnt"] = avg_cnt_data.tolist()
 
     return acquisition_dict
 
