@@ -7,12 +7,13 @@
 
 # -- include -----------------------------------------------------------------
 
-from typing import Any, Callable, List, Union
+from typing import Any, Callable, List, Union, Iterable
 from functools import partial
 from qcodes import validators as vals
 from qcodes import Instrument, InstrumentChannel, Parameter
 from qblox_instruments import InstrumentClass, InstrumentType
 from qblox_instruments.qcodes_drivers.sequencer import Sequencer
+from qblox_instruments.ieee488_2 import DummyBinnedAcquisitionData, DummyScopeAcquisitionData
 
 
 # -- class -------------------------------------------------------------------
